@@ -2,8 +2,13 @@
 
 __author__ = """Enric Tomas Grau Luque"""
 __email__ = 'patenric@gmail.com'
-__version__ = '0.0.8'
+__version__ = '0.1.4'
 
 
 """Import all the functions"""
-from .functions import *
\ No newline at end of file
+from .functions import *
+
+
+"""Include data file for examples."""
+# from pathlib import Path
+# PACKAGEDIR = Path(__file__).parent.absolute()
